AROSICS documentation
=====================

**This documentation is structured as follows:**

.. toctree::
   :maxdepth: 2

   about
   installation
   usage
   api_cli_reference
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
